/******************************************************************/
/*                                                                */
/* Module:       jb_device_info.h                                 */
/*                                                                */
/* Descriptions: Contain information of Altera devices.           */
/*                                                                */
/* Revisions:   1.0 02/22/02                                      */
/*				 .2 10/23/02									  */
/*				 Stratix JTAG ID-Code added						  */
/*				 .3 1/24/03										  */
/*				 Cyclone JTAG ID-Code added						  */
/*				 .4 6/3/03										  */
/*				 Stratix GX JTAG ID-Code added					  */
/*				 1C4 JTAG ID-Code added							  */
/*				 .5 6/1/04										  */
/*				 Stratix II EP2S60 JTAG ID-Code added			  */
/*				 .6 1/28/05										  */
/*				 Stratix II JTAG ID-Code added					  */
/*               Cyclone II EP2C35 JTAG ID-Code added			  */
/*				 .7 11/15/05									  */
/*               Cyclone II JTAG ID-Code added					  */
/*				 .8 05/29/06									  */
/*               BYPASS_DEV10 device info added					  */
/*				 .9 01/24/07									  */
/*				 Stratix II GX JTAG ID-Code added				  */
/*               Cyclone III EP3C25 JTAG ID-Code added			  */
/*		    2.0 	 04/26/07						 	          */
/*			Cyclone III all devices densities and package         */
/*			support added										  */
/*			2.1		 06/11/07									  */
/*			Arria GX all devices densities and package            */
/*			support added	                                      */
/*			Stratix III all devices densities and package         */
/*			support added										  */
/******************************************************************/

#ifndef JB_DEVICE_INFO_H
#define JB_DEVICE_INFO_H


#define MAX_DEV_FAMILY 17		/*how many device family listed? */
#define MAX_DEV_LIST   260

int start_of_device_family[MAX_DEV_FAMILY] = {
	0,   /* ACEX      */
	14,  /* APEX II   */
	24,  /* APEX 20K  */
	35,  /* APEX 20KC */
	47,  /* APEX 20KE */
	83,  /* FLEX 10KE */
	112, /* MERCURY   */
	114, /* STRATIX   */
	143, /* CYCLONE   */	//AKL4A22 Change from 145 to 143
	155, /* STRATIX GX */
	158, /* STRATIX II */
	174, /* CYCLONE II */
	189, /* NON ALTR */
	190, /* STRATIX II GX */
	196, /* CYCLONE III */
	226, /* ARRIA GX */
	237	 /* STRATIX III */
};

int MAX_JTAG_INIT_CLOCK[MAX_DEV_FAMILY] = {
	30,   /* ACEX      */
	175,  /* APEX II   */
	175,  /* APEX 20K  */
	175,  /* APEX 20KC */
	175,  /* APEX 20KE */
	30,   /* FLEX 10KE */
	175,  /* MERCURY   */
	175,  /* STRATIX   */
	175,  /* CYCLONE   */
	175,  /* STRATIX GX */
	300,  /* STRATIX II */
	300,  /* CYCLONE II */
	300,  /* NON ALTR */
	300,  /* STRATIX II GX */
	3181, /* CYCLONE III */
	300,  /* ARRIA GX */
	4436  /* STRATIX III */ 
};

char family_name[MAX_DEV_FAMILY][13] = {
	{"ACEX 1K"},
	{"APEX II"},
	{"APEX 20K"},
	{"APEX 20KC"},
	{"APEX 20KE"},
	{"FLEX 10KE"},
	{"MERCURY"},
	{"STRATIX"},
	{"CYCLONE"},
	{"STRATIX GX"},
	{"STRATIX II"},
	{"CYCLONE II"},
	{"BYPASS DEV"},
	{"STRATIX II GX"},
	{"CYCLONE III"},
	{"ARRIA GX"},
	{"STRATIX III"}
};

char device_name[MAX_DEV_LIST][20] = {
/* ACEX 1K */
	{"EP1K10F256"},/* start of ACEX 0 */
	{"EP1K10Q208"},//	1
	{"EP1K10T100"},//	2
	{"EP1K10T144"},//	3
	{"EP1K30F256"},//	4
	{"EP1K30Q208"},//	5
	{"EP1K30T144"},//	6
	{"EP1K50F256"},//	7
	{"EP1K50F484"},//	8
	{"EP1K50Q208"},//	9
	{"EP1K50T144"},//	10
	{"EP1K100F256"},//	11
	{"EP1K100F484"},//	12
	{"EP1K100Q208"},//	13
/* APEX II */
	{"EP2A15B724"},/* start of APEX II 14 */
	{"EP2A15F672"},//	15
	{"EP2A25B724"},//	16
	{"EP2A25F672"},//	17
	{"EP2A25F1020"},//	18
	{"EP2A40B724"},//	19
	{"EP2A40F672"},//	20
	{"EP2A40F1020"},//	21
	{"EP2A70B724"},//	22
	{"EP2A70F1508"},//	23
/* APEX 20K */
	{"EP20K100B356"},/* start of APEX 20K 24 */
	{"EP20K100F324"},//	25
	{"EP20K100Q208"},//	26
	{"EP20K100Q240"},//	27
	{"EP20K100T144"},//	28
	{"EP20K200B356"},//	29
	{"EP20K200F484"},//	30
	{"EP20K200R208"},//	31
	{"EP20K200R240"},//	32
	{"EP20K400B652"},//	33
	{"EP20K400F672"},//	34
/* APEX 20KC */
	{"EP20K200CB356"},/* start of APEX 20KC 35 */
	{"EP20K200CF484"},//	36
	{"EP20K200CQ208"},//	37
	{"EP20K200CQ240"},//	38
	{"EP20K400CB652"},//	39
	{"EP20K400CF672"},//	40
	{"EP20K600CB652"},//	41
	{"EP20K600CF672"},//	42
	{"EP20K600CF33"},//		43
	{"EP20K1000CB652"},//	44
	{"EP20K1000CF672"},//	45
	{"EP20K1000CF33"},//	46
/* APEX 20KE */
	{"EP20K30ET144"},/* start of APEX 20KE 47 */
	{"EP20K60EB356"},//	48
	{"EP20K60EF144"},//	49
	{"EP20K60EF324"},//	50
	{"EP20K60EQ208"},//	51
	{"EP20K60ET144"},//	52
	{"EP20K100EB356"},//	53
	{"EP20K100EF144"},//	54
	{"EP20K100EF324"},//	55
	{"EP20K100EQ208"},//	56
	{"EP20K100EQ240"},//	57
	{"EP20K100ET144"},//	58
	{"EP20K160EB356"},//	59
	{"EP20K160EF484"},//	60
	{"EP20K160EQ208"},//	61
	{"EP20K160EQ240"},//	62
	{"EP20K160ET144"},//	63
	{"EP20K200EB356"},//	64
	{"EP20K200EB652"},//	65
	{"EP20K200EF484"},//	66
	{"EP20K200EF672"},//	67
	{"EP20K200EQ208"},//	68
	{"EP20K200EQ240"},//	69
	{"EP20K300EB652"},//	70
	{"EP20K300EF672"},//	71
	{"EP20K300EQ240"},//	72
	{"EP20K400EB652"},//	73
	{"EP20K400EF672"},//	74
	{"EP20K600EB652"},//	75
	{"EP20K600EF672"},//	76
	{"EP20K600EF33"},//		77
	{"EP20K1000EB652"},//	78
	{"EP20K1000EF672"},//	79
	{"EP20K1000EF33"},//	80
	{"EP20K1500EB652"},//	81
	{"EP20K1500EF33"},//	82
/* FLEX 10KE */
	{"EPF10K30EF256"},/* start of FLEX 10KE 83 */
	{"EPF10K30EF484"},//	84
	{"EPF10K30EQ208"},//	85
	{"EPF10K30ET144"},//	86
	{"EPF10K50EF256"},//	87
	{"EPF10K50EQ240"},//	88
	{"EPF10K50ET144"},//	89
	{"EPF10K50SB356"},//	90
	{"EPF10K50SF256"},//	91
	{"EPF10K50SF484"},//	92
	{"EPF10K50SQ208"},//	93
	{"EPF10K50SQ240"},//	94
	{"EPF10K50ST144"},//	95
	{"EPF10K100EB356"},//	96
	{"EPF10K100EF256"},//	97
	{"EPF10K100EF484"},//	98
	{"EPF10K100EQ208"},//	99
	{"EPF10K100EQ240"},//	100
	{"EPF10K130EB356"},//	101
	{"EPF10K130EB600"},//	102
	{"EPF10K130EF484"},//	103
	{"EPF10K130EF672"},//	104
	{"EPF10K130EQ240"},//	105
	{"EPF10K200EB600"},//	106
	{"EPF10K200SB356"},//	107
	{"EPF10K200SB600"},//	108
	{"EPF10K200SF484"},//	109
	{"EPF10K200SF672"},//	110
	{"EPF10K200SR240"},//	111
/* MERCURY */
	{"EP1M120F484"},/* start of MERCURY 112 */
	{"EP1M350F780"},//		113
/* STRATIX */
	{"EP1S10B672"},/* start of STRATIX 114 */
	{"EP1S10F484"},//		115
	{"EP1S10F672"},//		116
	{"EP1S10F780"},//		117
	{"EP1S10B672ES"},//		118
	{"EP1S10F484ES"},//		119
	{"EP1S10F672ES"},//		120
	{"EP1S10F780ES"},//		121
	{"EP1S20B672"},//		122
	{"EP1S20F484"},//		123
	{"EP1S20F672"},//		124
	{"EP1S20F780"},//		125
	{"EP1S25B672"},//		126
	{"EP1S25F672"},//		127
	{"EP1S25F780"},//		128
	{"EP1S25F1020"},//		129
	{"EP1S30B956"},//		130
	{"EP1S30F780"},//		131
	{"EP1S30F1020"},//		132
	{"EP1S40B956"},//		133
	{"EP1S40F780"},//		134
	{"EP1S40F1020"},//		135
	{"EP1S40F1508"},//		136
	{"EP1S60B956"},//		137
	{"EP1S60F1020"},//		138
	{"EP1S60F1508"},//		139
	{"EP1S80B956"},//		140
	{"EP1S80F1020"},//		141
	{"EP1S80F1508"},//		142
/* CYCLONE */
	{"EP1C20F324"},/* start of CYCLONE 143 */
	{"EP1C20F400"},//		144
	{"EP1C12F256"},//		145
	{"EP1C12F324"},//		146
	{"EP1C12Q240"},//		147
	{"EP1C6F256"},//		148
	{"EP1C6Q240"},//		149
	{"EP1C6T144"},//		150
	{"EP1C4F400"},//		151
	{"EP1C4F324"},//		152
	{"EP1C3T100"},//		153
	{"EP1C3T144"},//		154
/* STRATIX GX */
	{"EP1SGX40"},/* start of STRATIX GX 155 */
	{"EP1SGX25"},//		156
	{"EP1SGX10"},//		157
/* STRATIX II ES*/
	{"EP2S60F484ES"},///* start of STRATIX II ES 158 */	
	{"EP2S60F672ES"},//		159
	{"EP2S60F1020ES"},//	160
/* STRATIX II */
	{"EP2S15F484"},///* start of STRATIX II 161 */
	{"EP2S15F672"},//		162
	{"EP2S30F484"},//		163
	{"EP2S30F672"},//		164
	{"EP2S60F484"},//		165
	{"EP2S60F672"},//		166
	{"EP2S60F1020"},//		167
	{"EP2S90F1020"},//		168
	{"EP2S90F1508"},//		169
	{"EP2S130F1020"},//		170
	{"EP2S130F1508"},//		171
	{"EP2S180F1020"},//		172
	{"EP2S180F1508"},//		173
/* CYCLONE II */
	{"EP2C35F484"},///* start of CYCLONE II 174 */
	{"EP2C35F672"},//		175
	{"EP2C5T144"},//		176
	{"EP2C5Q208"},//		177	
	{"EP2C5F256"},//		178
	{"EP2C8T144"},//		179	
	{"EP2C8Q208"},//		180
	{"EP2C8F256"},//		181	
	{"EP2C20Q240"},//		182
	{"EP2C20F256"},//		183	
	{"EP2C20F484"},//		184
	{"EP2C50F484"},//		185	
	{"EP2C50F672"},//		186
	{"EP2C70F672"},//		187	
	{"EP2C70F896"},//		188	
	{"BYPASS_DEV10"},//		189		//Bypass device on the JTAG chain	
/* STRATIX II GX */
	{"EP2SGX30F780"},///* start of STRATIX II GX 190 */
	{"EP2SGX60F780"},//		191
	{"EP2SGX60F1152"},//	192
	{"EP2SGX90F1152"},//	193
	{"EP2SGX90F1508"},//	194
	{"EP2SGX130F1508"},//	195
/* CYCLONE III */
	{"EP3C25F324"},///* start of CYCLONE III 196 */
	{"EP3C25E144"},//		197
	{"EP3C25Q240"},//		198
	{"EP3C25F256"},//		199
	{"EP3C25U256"},//		200
	{"EP3C5E144"},//		201
	{"EP3C5F256"},//		202
	{"EP3C5U256"},//		203
	{"EP3C10E144"},//		204
	{"EP3C10F256"},//		205
	{"EP3C10U256"},//		206
	{"EP3C16E144"},//		207
	{"EP3C16Q240"},//		208
	{"EP3C16F256"},//		209
	{"EP3C16U256"},//		210
	{"EP3C16F484"},//		211
	{"EP3C16U484"},//		212
	{"EP3C40Q240"},//		213
	{"EP3C40F324"},//		214
	{"EP3C40F484"},//		215
	{"EP3C40U484"},//		216
	{"EP3C40U780"},//		217
	{"EP3C55F484"},//		218
	{"EP3C55U484"},//		219
	{"EP3C55U780"},//		220
	{"EP3C80F484"},//		221
	{"EP3C80U484"},//		222
	{"EP3C80F780"},//		223
	{"EP3C120F484"},//		224
	{"EP3C120F780"},		///*end of Cyclone III*/// 225
/* ARRIA GX */
	{"EP1AGX20F484"},//		226
	{"EP1AGX20F780"},//		227
	{"EP1AGX35F484"},//		228
	{"EP1AGX35F780"},//		229
	{"EP1AGX50F484"},//		230
	{"EP1AGX50F780"},//		231
	{"EP1AGX50F1152"},//	232
	{"EP1AGX60F484"},//		233
	{"EP1AGX60F780"},//		234
	{"EP1AGX60F1152"},//	235
	{"EP1AGX90F1152"},		///*end of Arria GX*/// 236
/* STRATIX III */
	{"EP3SL50F484"},//		237
	{"EP3SL50F780"},//		238
	{"EP3SL70F484"},//		239
	{"EP3SL70F780"},//		240
	{"EP3SL110F780"},//		241
	{"EP3SL110F1152"},//	242
	{"EP3SL150F780"},//		243
	{"EP3SL150F1152"},//	244
	{"EP3SL200F780"},//		245
	{"EP3SL200F1152"},//	246
	{"EP3SL200F1517"},//	247
	{"EP3SL340F1152"},//	248
	{"EP3SL340F1517"},//	249
	{"EP3SL340F1760"},//	250
	{"EP3SE50F484"},//		251
	{"EP3SE50F780"},//		252
	{"EP3SE80F780"},//		253
	{"EP3SE80F1152"},//		254
	{"EP3SE110F780"},//		255
	{"EP3SE110F1152"},//	256
	{"EP3SE260F780"},//		257
	{"EP3SE260F1152"},//	258
	{"EP3SE260F1517"}		///*end of Arria GX*/// 259
	};

unsigned int device_info[MAX_DEV_LIST][4] = {
/* Device,        Idcode,   Max      Conf_done Instruction */
/*                          JTAG     JTAG      Length      */
/*                          Sequence,Sequence,             */ 
/* ACEX 1K */
	/* 10F256     */ {0x110100DD, 146, 146, 10},	//0
	/* 10Q208     */ {0x110100DD, 146, 146, 10},	//1
	/* 10T100     */ {0x110100DD, 146, 146, 10},	//2
	/* 10T144     */ {0x110100DD, 146, 146, 10},	//3
	/* 30F256     */ {0x110300DD, 230, 230, 10},	//4
	/* 30Q208     */ {0x110300DD, 230, 230, 10},	//5
	/* 30T144     */ {0x110300DD, 230, 230, 10},	//6
	/* 50F256     */ {0x110500DD, 266, 266, 10},	//7
	/* 50F484     */ {0x110500DD, 266, 266, 10},	//8
	/* 50Q208     */ {0x110500DD, 266, 266, 10},	//9
	/* 50T144     */ {0x110500DD, 266, 266, 10},	//10
	/* 100F256    */ {0x201000DD, 350, 350, 10},	//11
	/* 100F484    */ {0x201000DD, 350, 350, 10},	//12
	/* 100Q208    */ {0x201000DD, 350, 350, 10},	//13
/* APEX II */
	/* 15B724     */ {0xC4000DD, 508, 191, 10},		//14
	/* 15F672     */ {0xC4000DD, 508, 191, 10},		//15
	/* 25B724     */ {0xC6000DD, 628, 251, 10},		//16
	/* 25F672     */ {0xC6000DD, 628, 251, 10},		//17
	/* 25F1020    */ {0xC6000DD, 628, 251, 10},		//18
	/* 40B724     */ {0xD0000DD, 776, 293, 10},		//19
	/* 40F672     */ {0xD0000DD, 776, 293, 10},		//20
	/* 40F1020    */ {0xD0000DD, 776, 293, 10},		//21
	/* 70B724     */ {0xE0000DD, 1076, 443, 10},	//22
	/* 70F1508    */ {0XE0000DD, 1076, 443, 10},	//23
/* APEX 20K */
	/* 100B356    */ {0x04160DD, 262, 98, 10},		//24
	/* 100F324    */ {0x04160DD, 262, 98, 10},		//25
	/* 100Q208    */ {0x04160DD, 262, 98, 10},		//26
	/* 100Q240    */ {0x04160DD, 262, 98, 10},		//27
	/* 100T144    */ {0x04160DD, 262, 98, 10},		//28
	/* 200B356    */ {0x08320DD, 392, 163, 10},		//29
	/* 200F484    */ {0x08320DD, 392, 163, 10},		//30
	/* 200R208    */ {0x08320DD, 392, 163, 10},		//31
	/* 200R240    */ {0x08320DD, 392, 163, 10},		//32
	/* 400B652    */ {0x16640DD, 512, 193, 10},		//33
	/* 400F672    */ {0x16640DD, 512, 193, 10},		//34
/* APEX 20KC */
	/* 200CB356   */ {0x82000DD, 388, 159, 10},		//35
	/* 200CF484   */ {0x82000DD, 388, 159, 10},		//36
	/* 200CQ208   */ {0x82000DD, 388, 159, 10},		//37
	/* 200CQ240   */ {0x82000DD, 388, 159, 10},		//38
	/* 400CB652   */ {0x84000DD, 502, 189, 10},		//39
	/* 400CF672   */ {0x84000DD, 502, 189, 10},		//40
	/* 600CB652   */ {0x84000DD, 602, 239, 10},		//41
	/* 600CF672   */ {0x84000DD, 602, 239, 10},		//42
	/* 600CF33    */ {0x84000DD, 602, 239, 10},		//43
	/* 1000CB652  */ {0x90000DD, 730, 271, 10},		//44
	/* 1000CF672  */ {0x90000DD, 730, 271, 10},		//45
	/* 1000CF33   */ {0x90000DD, 730, 271, 10},		//46
/* APEX 20KE */
	/* 30ET144    */ {0x80300DD, 140, 47, 10},		//47
	/* 60EB356    */ {0x80600DD, 208, 69, 10},		//48
	/* 60EF144    */ {0x80600DD, 208, 69, 10},		//49
	/* 60EF324    */ {0x80600DD, 208, 69, 10},		//50
	/* 60EQ208    */ {0x80600DD, 208, 69, 10},		//51
	/* 60ET144    */ {0x80600DD, 208, 69, 10},		//52
	/* 100EB356   */ {0x81000DD, 258, 94, 10},		//53
	/* 100EF144   */ {0x81000DD, 258, 94, 10},		//54
	/* 100EF324   */ {0x81000DD, 258, 94, 10},		//55
	/* 100EQ208   */ {0x81000DD, 258, 94, 10},		//56
	/* 100EQ240   */ {0x81000DD, 258, 94, 10},		//57
	/* 100ET144   */ {0x81000DD, 258, 94, 10},		//58
	/* 160EB356   */ {0x81600DD, 328, 129, 10},		//59
	/* 160EF484   */ {0x81600DD, 328, 129, 10},		//60
	/* 160EQ208   */ {0x81600DD, 328, 129, 10},		//61
	/* 160EQ240   */ {0x81600DD, 328, 129, 10},		//62
	/* 160ET144   */ {0x81600DD, 328, 129, 10},		//63
	/* 200EB356   */ {0x82000DD, 388, 159, 10},		//64
	/* 200EB652   */ {0x82000DD, 388, 159, 10},		//65
	/* 200EF484   */ {0x82000DD, 388, 159, 10},		//66
	/* 200EF672   */ {0x82000DD, 388, 159, 10},		//67
	/* 200EQ208   */ {0x82000DD, 388, 159, 10},		//68
	/* 200EQ240   */ {0x82000DD, 388, 159, 10},		//69
	/* 300EB652   */ {0x83000DD, 422, 149, 10},		//70
	/* 300EB672   */ {0x83000DD, 422, 149, 10},		//71
	/* 300EQ240   */ {0x83000DD, 422, 149, 10},		//72
	/* 400EB652   */ {0x84000DD, 502, 189, 10},		//73
	/* 400EF672   */ {0x84000DD, 502, 189, 10},		//74
	/* 600EB652   */ {0x84000DD, 602, 239, 10},		//75
	/* 600EF672   */ {0x84000DD, 602, 239, 10},		//76
	/* 600EF33    */ {0x84000DD, 602, 239, 10},		//77
	/* 1000EB652  */ {0x90000DD, 730, 271, 10},		//78
	/* 1000EF672  */ {0x90000DD, 730, 271, 10},		//79
	/* 1000EF33   */ {0x90000DD, 730, 271, 10},		//80
	/* 1500EB652  */ {0x95000DD, 834, 323, 10},		//81
	/* 1500EF33   */ {0x95000DD, 834, 323, 10},		//82
/* FLEX 10KE */
	/* 30EF256    */ {0x110300DD, 230, 230, 10},	//83
	/* 30EF484    */ {0x110300DD, 230, 230, 10},	//84
	/* 30EQ208    */ {0x110300DD, 230, 230, 10},	//85
	/* 30ET144    */ {0x110300DD, 230, 230, 10},	//86
	/* 50EF256    */ {0x110500DD, 266, 266, 10},	//87
	/* 50EQ240    */ {0x110500DD, 266, 266, 10},	//88
	/* 50ET144    */ {0x110500DD, 266, 266, 10},	//89
	/* 50SB356    */ {0x110500DD, 266, 266, 10},	//90
	/* 50SF256    */ {0x110500DD, 266, 266, 10},	//91
	/* 50SF484    */ {0x110500DD, 266, 266, 10},	//92
	/* 50SQ208    */ {0x110500DD, 266, 266, 10},	//93
	/* 50SQ240    */ {0x110500DD, 266, 266, 10},	//94
	/* 50ST144    */ {0x110500DD, 266, 266, 10},	//95
	/* 100EB356   */ {0x201000DD, 350, 350, 10},	//96
	/* 100EF256   */ {0x201000DD, 350, 350, 10},	//97
	/* 100EF484   */ {0x201000DD, 350, 350, 10},	//98
	/* 100EQ208   */ {0x201000DD, 350, 350, 10},	//99
	/* 100EQ240   */ {0x201000DD, 350, 350, 10},	//100
	/* 130EB356   */ {0x101300DD, 436, 436, 10},	//101
	/* 130EB600   */ {0x101300DD, 436, 436, 10},	//102
	/* 130EF484   */ {0x101300DD, 436, 436, 10},	//103
	/* 130EF672   */ {0x101300DD, 436, 436, 10},	//104
	/* 130EQ240   */ {0x101300DD, 436, 436, 10},	//105
	/* 200EB600   */ {0x102000DD, 482, 482, 10},	//106
	/* 200SB356   */ {0x102000DD, 482, 482, 10},	//107
	/* 200SB600   */ {0x102000DD, 482, 482, 10},	//108
	/* 200SF484   */ {0x102000DD, 482, 482, 10},	//109
	/* 200SF672   */ {0x102000DD, 482, 482, 10},	//110
	/* 200SR240   */ {0x102000DD, 482, 482, 10},	//111
/* MERCURY */
	/* 120F484    */ {0x30000DD, 375, 5, 10},		//112
	/* 350F780    */ {0x30010DD, 565, 7, 10},		//113
/* STRATIX */
	/* 10B672     */ {0x20010DD, 439, 391, 10},		//114
	/* 10F484     */ {0x20010DD, 439, 391, 10},		//115
	/* 10F672     */ {0x20010DD, 439, 391, 10},		//116
	/* 10F780     */ {0x20010DD, 439, 391, 10},		//117
	/* 10B672ES   */ {0x20030DD, 439, 391, 10},		//118
	/* 10F484ES   */ {0x20030DD, 439, 391, 10},		//119
	/* 10F672ES   */ {0x20030DD, 439, 391, 10},		//120
	/* 10F780ES   */ {0x20030DD, 439, 391, 10},		//121
	/* 20B672     */ {0x20020DD, 599, 533, 10},		//122
	/* 20F484     */ {0x20020DD, 599, 533, 10},		//123
	/* 20F672     */ {0x20020DD, 599, 533, 10},		//124
	/* 20F780     */ {0x20020DD, 599, 533, 10},		//125
	/* 25B672     */ {0x20030DD, 719, 635, 10},		//126
	/* 25F672     */ {0x20030DD, 719, 635, 10},		//127
	/* 25F780     */ {0x20030DD, 719, 635, 10},		//128
	/* 25F1020    */ {0x20030DD, 719, 635, 10},		//129
	/* 30B956     */ {0x20040DD, 751, 667, 10},		//130
	/* 30F780     */ {0x20040DD, 751, 667, 10},		//131
	/* 30F1020    */ {0x20040DD, 751, 667, 10},		//132
	/* 40B956     */ {0x20050DD, 843, 741, 10},		//133
	/* 40F780	  */ {0x20050DD, 843, 741, 10},		//134
	/* 40F1020    */ {0x20050DD, 843, 741, 10},		//135
	/* 40F1508    */ {0x20050DD, 843, 741, 10},		//136
	/* 60B956     */ {0x20060DD, 1043, 923, 10},	//137
	/* 60F1020    */ {0x20060DD, 1043, 923, 10},	//138
	/* 60F1508    */ {0x20060DD, 1043, 923, 10},	//139
	/* 80B956     */ {0x20070DD, 1259, 1121, 10},	//140
	/* 80F1020    */ {0x20070DD, 1259, 1121, 10},	//141
	/* 80F1508    */ {0x20070DD, 1259, 1121, 10},	//142
/* CYCLONE */	
	/* 20F324	  */ {0x20840DD, 310, 197, 10},		//143
	/* 20F400	  */ {0x20840DD, 310, 197, 10},		//144
	/* 12F256	  */ {0x20830DD, 258, 163, 10},		//145
	/* 12F324	  */ {0x20830DD, 258, 163, 10},		//146
	/* 12Q240	  */ {0x20830DD, 258, 163, 10},		//147
	/* 6F256	  */ {0x20820DD, 194, 121, 10},		//148
	/* 6Q240	  */ {0x20820DD, 194, 121, 10},		//149
	/* 6T144	  */ {0x20820DD, 194, 121, 10},		//150
	/* 4F400	  */ {0x20850DD, 310, 198, 10},		//151
	/* 4F324	  */ {0x20850DD, 310, 198, 10},		//152
	/* 3T100	  */ {0x20810DD, 113, 69, 10},		//153
	/* 3T144	  */ {0x20810DD, 113, 69, 10},		//154
/* STRATIX GX */
	/* 1SGX40     */ {0x20450DD, 647, 545, 10},		//155
	/* 1SGX25     */ {0x20430DD, 555, 471, 10},		//156
	/* 1SGX10	  */ {0x20410DD, 343, 295, 10},		//157
/* STRATIX II ES*/
	/* 2S60F484ES */ {0x20930DD, 732, 731, 10},		//158
	/* 2S60F672ES */ {0x20930DD, 732, 731, 10},		//159
	/* 2S60F1020ES*/ {0x20930DD, 732, 731, 10},		//160
/* STRATIX II */
	/* 2S15F484 */   {0x20910DD, 380, 379, 10},		//161
	/* 2S15F672 */   {0x20910DD, 380, 379, 10},		//162
	/* 2S30F484 */   {0x20920DD, 564, 563, 10},		//163
	/* 2S30F672 */   {0x20920DD, 564, 563, 10},		//164
	/* 2S60F484 */   {0x120930DD,732, 731, 10},		//165
	/* 2S60F672 */   {0x120930DD,732, 731, 10},		//166
	/* 2S60F1020*/   {0x120930DD,732, 731, 10},		//167
	/* 2S90F1020*/   {0x20940DD, 916, 915, 10},		//168
	/* 2S90F1508*/   {0x20940DD, 916, 915, 10},		//169
	/* 2S130F1020*/  {0x20950DD, 1140,1139,10},		//170
	/* 2S130F1508*/  {0x20950DD, 1140,1139,10},		//171
	/* 2S180F1020*/  {0x20960DD, 1316,1315,10},		//172
	/* 2S180F1508*/  {0x20960DD, 1316,1315,10},		//173
/* CYCLONE II */
	/* 2C35F484 */   {0x20B40DD, 483, 296, 10},		//174
	/* 2C35F672 */   {0x20B40DD, 483, 296, 10}, 	//175
	/* 2C5T144	*/	 {0x20B10DD, 166,  97, 10},		//176
	/* 2C5Q208	*/	 {0x20B10DD, 166,  97, 10},		//177	
	/* 2C5F256	*/	 {0x20B10DD, 166,  97, 10},		//178	
	/* 2C8T144	*/	 {0x20B20DD, 199, 119, 10},		//179
	/* 2C8Q208	*/	 {0x20B20DD, 199, 119, 10},		//180	
	/* 2C8F256	*/	 {0x20B20DD, 199, 119, 10},		//181		
	/* 2C20Q240	*/	 {0x20B30DD, 323, 193, 10},		//182
	/* 2C20F256	*/	 {0x20B30DD, 323, 193, 10},		//183
	/* 2C20F484	*/	 {0x20B30DD, 323, 193, 10},		//184
	/* 2C50F484	*/	 {0x20B50DD, 458, 280, 10},		//185	
	/* 2C50F672	*/	 {0x20B50DD, 458, 280, 10},		//186
	/* 2C70F672	*/	 {0x20B60DD, 630, 391, 10},		//187
	/* 2C70F896	*/	 {0x20B60DD, 630, 391, 10},		//188
/* BYPASS_DEVICE */
/* BYPASS_DEV10  */	 {0x0000000, 000, 000, 10},		//189		//Bypass device with 10-bit Instruction Length
/* STRATIX II GX */
	/* 2SGX30F780 */ {0x20E10DD, 564, 563, 10},		//190
	/* 2SGX60F780 */ {0x20E20DD, 732, 731, 10},		//191
	/* 2SGX60F1152*/ {0x20E20DD, 732, 731, 10},		//192
	/* 2SGX90F1152*/ {0x20E30DD, 672, 671, 10},		//193
	/* 2SGX90F1508*/ {0x20E30DD, 672, 671, 10},		//194
	/* 2SGX130F1508*/{0x20E40DD, 816, 815, 10},		//195
/* CYCLONE III */
	/* 3C25F324*/    {0x20F30DD, 244, 149, 10},			//196
	/* 3C25E144*/	 {0x20F30DD, 244, 149, 10},			//197
	/* 3C25Q240*/	 {0x20F30DD, 244, 149, 10},			//198
	/* 3C25F256*/    {0x20F30DD, 244, 149, 10},			//199
	/* 3C25U256*/    {0x20F30DD, 244, 149, 10},			//200
	/* 3C5E144*/	 {0x20F10DD, 201, 126, 10},			//201
	/* 3C5F256*/	 {0x20F10DD, 201, 126, 10},			//202
	/* 3C5U256*/ 	 {0x20F10DD, 201, 126, 10},			//203
	/* 3C10E144*/    {0x20F10DD, 201, 126, 10},			//204
	/* 3C10F256*/    {0x20F10DD, 201, 126, 10},			//205
	/* 3C10U256*/    {0x20F10DD, 201, 126, 10},			//206
	/* 3C16E144*/    {0x20F20DD, 360, 224, 10},			//207
	/* 3C16Q240*/    {0x20F20DD, 360, 224, 10},			//208
	/* 3C16F256*/    {0x20F20DD, 360, 224, 10},			//209
	/* 3C16U256*/    {0x20F20DD, 360, 224, 10},			//210
	/* 3C16F484*/    {0x20F20DD, 360, 224, 10},			//211
	/* 3C16U484*/    {0x20F20DD, 360, 224, 10},			//212
	/* 3C40Q240*/    {0x20F40DD, 544, 343, 10},			//213
	/* 3C40F324*/    {0x20F40DD, 544, 343, 10},			//214
	/* 3C40F484*/    {0x20F40DD, 544, 343, 10},			//215
	/* 3C40U484*/    {0x20F40DD, 544, 343, 10},			//216
	/* 3C40U780*/    {0x20F40DD, 544, 343, 10},			//217
	/* 3C55F484*/    {0x20F50DD, 388, 241, 10},			//218
	/* 3C55U484*/    {0x20F50DD, 388, 241, 10},			//219
	/* 3C55U780*/    {0x20F50DD, 388, 241, 10},			//220
	/* 3C80F484*/    {0x20F60DD, 438, 271, 10},			//221
	/* 3C80U484*/    {0x20F60DD, 438, 271, 10},			//222
	/* 3C80F780*/    {0x20F60DD, 438, 271, 10},			//223
	/* 3C120F484*/   {0x20F70DD, 540, 336, 10},			//224
	/* 3C120F780*/   {0x20F70DD, 540, 336, 10},			//225
/* ARRIA GX */
	/* 1AGX20F484*/   {0x21210DD, 440, 439, 10},		//226
	/* 1AGX20F780*/   {0x21210DD, 440, 439, 10},		//227
	/* 1AGX35F484*/   {0x21210DD, 440, 439, 10},		//228
	/* 1AGX35F780*/   {0x21210DD, 440, 439, 10},		//229
	/* 1AGX50F484*/   {0x21220DD, 556, 555, 10},		//230
	/* 1AGX50F780*/   {0x21220DD, 556, 555, 10},		//231
	/* 1AGX50F1152*/  {0x21220DD, 556, 555, 10},		//232
	/* 1AGX60F484*/   {0x21220DD, 556, 555, 10},		//233
	/* 1AGX60F780*/   {0x21220DD, 556, 555, 10},		//234
	/* 1AGX60F1152*/  {0x21220DD, 556, 555, 10},		//235
	/* 1AGX90F1152*/  {0x21230DD, 672, 671, 10}, 		//236
/* STRATIX III */
	/* EP3SL50F484*/  {0x21080DD, 502, 122, 10},		//237
	/* EP3SL50F780*/  {0x21080DD, 502, 122, 10},		//238
	/* EP3SL70F484*/  {0x21010DD, 502, 122, 10},		//239
	/* EP3SL70F780*/  {0x21010DD, 502, 122, 10},		//240
	/* EP3SL110F780*/ {0x21090DD, 758, 186, 10},		//241
	/* EP3SL110F1152*/{0x21090DD, 758, 186, 10},		//242
	/* EP3SL150F780*/ {0x21020DD, 758, 186, 10},		//243
	/* EP3SL150F1152*/{0x21020DD, 758, 186, 10},		//244
	/* EP3SL200F780*/ {0x21030DD, 894, 190, 10},		//245
	/* EP3SL200F1152*/{0x21030DD, 894, 190, 10},		//246
	/* EP3SL200F1517*/{0x21030DD, 894, 190, 10}, 		//247
	/* EP3SL340F1152*/{0x21050DD,1134, 278, 10},		//248
	/* EP3SL340F1517*/{0x21050DD,1134, 278, 10},		//249
	/* EP3SL340F1760*/{0x21050DD,1134, 278, 10},		//250
	/* EP3SE50F484*/  {0x21060DD, 502, 122, 10},		//251
	/* EP3SE50F780*/  {0x21060DD, 502, 122, 10},		//252
	/* EP3SE80F780*/  {0x210A0DD, 502, 122, 10},		//253
	/* EP3SE80F1152*/ {0x210A0DD, 502, 122, 10},		//254
	/* EP3SE110F780*/ {0x21070DD, 758, 186, 10},		//255
	/* EP3SE110F1152*/{0x21070DD, 758, 186, 10},		//256
	/* EP3SE260F780*/ {0x21040DD, 990, 238, 10},		//257
	/* EP3SE260F1152*/{0x21040DD, 990, 238, 10}, 		//258
	/* EP3SE260F1517*/{0x21040DD, 990, 238, 10} 		//259
	};

#endif

















